# This python module listens for publications from a MQTT broker,
# and creates a call file which will cause Asterisk to call a number
# and play a sound file
# Written by Anders Fongen, FHS/CIS, sept 2019
import paho.mqtt.client as mqtt
import json
import os
import tempfile

TOPIC="asterisk/alarm"
PSBROKER="localhost"
CLIENTNAME="AsteriskAdapter"
SPOOLAREA = "/var/spool/asterisk/outgoing/"

# Change the two next lines if this code is moved to a different computer!!
ASTERISKUID = 115
ASTERISKGID = 121

class Document():

    def __init__(self,jsonTxt):
        self.docObj = json.loads(jsonTxt)

    def getExtension(self): return self.docObj['extension']
    def getSoundfile(self): return self.docObj['soundfile']
    def getCallerId(self): return int(self.docObj['callerId'])

    def getCallstring(self):
        return "Channel: Local/%s@anonymous\nCallerId: Alarm <%s>\nApplication: Playback\nData: %s\n" \
                % (self.getExtension(),self.getCallerId(),self.getSoundfile())

# This class is the main thread in the program, which connects to the MQTT
# browser, receives documents and adds/updates them into the CMS database
class DocumentReceiver():
    def __init__(self,broker=PSBROKER,clientname=CLIENTNAME):
        self.client = mqtt.Client(clientname)
        self.client.connect(broker)
        self.client.subscribe(TOPIC)
        self.client.on_message=self.on_message
        print ("Ready to receive")
        self.client.loop_forever()

    def on_message(self,client,userdata,message):
        print ("Message received")
        doc = Document(str(message.payload.decode("utf-8")))
        # Create a call file
        filename = tempfile.mktemp()
        file = open(filename,"w")
        callstring = doc.getCallstring()
        print (callstring)
        file.write(callstring)
        file.close()
        # Set asterisk ownership
        os.chown(filename,ASTERISKUID,ASTERISKGID)
        # Move file to Asterisk spool area	
        newfilename = SPOOLAREA + os.path.basename(filename)
        os.rename(filename,newfilename)


if __name__ == "__main__":

        dr = DocumentReceiver()


	

